library(testthat)
library(eeptools)

test_check("eeptools")
# 
# source("R/statamode.R")
# test_file("tests/testthat/test-statamode.R")
# source("R/decomma.R")
# test_file("tests/testthat/test-decomma.R")
# source("R/modsims.R")
# test_file("tests/testthat/test-gelmansim.R")
